##########
User Guide
##########

Welcome to MUSICA! MUSICA stands for the Multiscale Interface for Chemistry and Aerosols. 
This user guide provides an overview of the MUSICA library code and how to use it.

.. note::
   The MUSICA library is separate from the configurations of CESM. All of the code here is in support of
   modeling needs that could apply to any model.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   fortran_c
   configurations